[tor-commits] [tor/master] Rename routerstatus_version_supports_ntor to *_supports_extend2_cells

nickm at torproject.org nickm at torproject.org
Tue Nov 1 17:05:55 UTC 2016


commit 3158777d35d8e03fdd77d9c227c2d04538d5fff3
Author: teor <teor2345 at gmail.com>
Date:   Thu Oct 27 15:53:49 2016 +1100

    Rename routerstatus_version_supports_ntor to *_supports_extend2_cells
    
    This helps avoid the confusion that caused bug 20472.
    Bugfix on commit 10aa913 from #19163 in tor-0.2.9.3-alpha.
---
 src/or/networkstatus.c |  6 +++---
 src/or/routerlist.c    | 14 ++++++++------
 src/or/routerlist.h    |  4 ++--
 3 files changed, 13 insertions(+), 11 deletions(-)

diff --git a/src/or/routerlist.h b/src/or/routerlist.h
index 47e5445..606e908 100644
--- a/src/or/routerlist.h
+++ b/src/or/routerlist.h
@@ -207,8 +207,8 @@ int routerinfo_incompatible_with_extrainfo(const crypto_pk_t *ri,
                                            signed_descriptor_t *sd,
                                            const char **msg);
 int routerinfo_has_curve25519_onion_key(const routerinfo_t *ri);
-int routerstatus_version_supports_ntor(const routerstatus_t *rs,
-                                       int allow_unknown_versions);
+int routerstatus_version_supports_extend2_cells(const routerstatus_t *rs,
+                                                int allow_unknown_versions);
 
 void routerlist_assert_ok(const routerlist_t *rl);
 const char *esc_router_info(const routerinfo_t *router);





More information about the tor-commits mailing list
diff --git a/src/or/networkstatus.c b/src/or/networkstatus.c
index f30fe16..49baeb8 100644
--- a/src/or/networkstatus.c
+++ b/src/or/networkstatus.c
@@ -2360,10 +2360,10 @@ client_would_use_router(const routerstatus_t *rs, time_t now,
     /* We'd drop it immediately for being too old. */
     return 0;
   }
-  if (!routerstatus_version_supports_ntor(rs, 1)) {
-    /* We'd ignore it because it doesn't support ntor.
+  if (!routerstatus_version_supports_extend2_cells(rs, 1)) {
+    /* We'd ignore it because it doesn't support EXTEND2 cells.
      * If we don't know the version, download the descriptor so we can
      * check if it supports ntor. */
     return 0;
   }
   return 1;
@@ -2360,10 +2360,10 @@ client_would_use_router(const routerstatus_t *rs, time_t now,
      * If we don't know the version, download the descriptor so we can
-     * check if it supports ntor. */
+     * check if it supports EXTEND2 cells and ntor. */
     return 0;
   }
diff --git a/src/or/routerlist.c b/src/or/routerlist.c
index 85eb999..56c0522 100644
--- a/src/or/routerlist.c
+++ b/src/or/routerlist.c
@@ -2344,9 +2344,10 @@ router_add_running_nodes_to_smartlist(smartlist_t *sl, int allow_invalid,
       continue;
     if (node_is_unreliable(node, need_uptime, need_capacity, need_guard))
       continue;
-    /* Don't choose nodes if we are certain they can't do ntor */
-    if (node->rs && !routerstatus_version_supports_ntor(node->rs, 1))
+    /* Don't choose nodes if we are certain they can't do EXTEND2 cells */
+    if (node->rs && !routerstatus_version_supports_extend2_cells(node->rs, 1))
       continue;
+    /* Don't choose nodes if we are certain they can't do ntor. */
     if ((node->ri || node->md) && !node_has_curve25519_onion_key(node))
       continue;
     /* Choose a node with an OR address that matches the firewall rules */
@@ -5609,13 +5610,14 @@ routerinfo_has_curve25519_onion_key(const routerinfo_t *ri)
   return 1;
 }
 
 /* Is rs running a tor version known to support ntor?
  * If allow_unknown_versions is true, return true if we can't tell
  * (from a versions line or a protocols line) whether it supports ntor.
  * Otherwise, return false if the version is unknown. */
 int
-routerstatus_version_supports_ntor(const routerstatus_t *rs,
-                                   int allow_unknown_versions)
+routerstatus_version_supports_extend2_cells(const routerstatus_t *rs,
+                                            int allow_unknown_versions)
 {
   if (!rs) {
     return allow_unknown_versions;
@@ -5609,13 +5610,14 @@ routerinfo_has_curve25519_onion_key(const routerinfo_t *ri)
 }
 
-/* Is rs running a tor version known to support ntor?
+/* Is rs running a tor version known to support EXTEND2 cells?
  * If allow_unknown_versions is true, return true if we can't tell
@@ -5609,13 +5610,14 @@ routerinfo_has_curve25519_onion_key(const routerinfo_t *ri)
  * If allow_unknown_versions is true, return true if we can't tell
- * (from a versions line or a protocols line) whether it supports ntor.
+ * (from a versions line or a protocols line) whether it supports extend2
+ * cells.
  * Otherwise, return false if the version is unknown. */
 int